@@ -9,7 +9,7 @@ class PointConstraint(VectorConstraint):
     Pulls the xyz position of a node to a target point.
     """
     def __init__(self, node=None, point=None, weight=1.0):
-        super(PointConstraint, self).__init__(node, point, weight)
+        super(PointConstraint, self).__init__(key=node, target=point, weight=weight)
 
     def reference(self, data):
         """
